@@ -128,6 +128,10 @@ class Database:
                     elif freq == '1D':
                         df = df[['date','open','high','low','close','volume']]
 
+            df['date'] = df['date'].astype(int)
+            if 'T' in freq:
+                df['time'] = df['time'].astype(int)
+
             return df
     
     def get_us_stock_ohlc(self, code, start_date, end_date):
